@@ -56,6 +56,8 @@ void NewProgramWindow::load()
 void NewProgramWindow::load(QString name, QList <QString> exercises)
 {
     QList <QString> list;
+    QModelIndex index;
+
     list = xml->openAll();
     qDebug() << "NewProgramWindow::load 1";
     if(list.isEmpty())
@@ -79,10 +81,9 @@ void NewProgramWindow::load(QString name, QList <QString> exercises)
 
     while(!exercises.isEmpty())
     {
-        QModelIndex index = model->index(list.takeFirst().toInt(),0);
-        lstExercises->selectionModel()->setCurrentIndex(index, QItemSelectionModel::Select);
+        index = model->index(exercises.takeFirst().toInt(),0);
+        lstExercises->selectionModel()->select(index, QItemSelectionModel::Select);
     }
-
 }
 
 void NewProgramWindow::saveExercise()
