@@ -748,7 +748,7 @@ void XML::exportExercises(QModelIndexList name)
 }
 
 void XML::saveEx(QString name, QString group, QString muscle,
-                    QString info)
+                    QString info, QString newName)
 {
     QDomDocument doc( "Exercises" );
     QString str = "/home/user/.qexercise";
@@ -794,16 +794,19 @@ void XML::saveEx(QString name, QString group, QString muscle,
    }
    file.close();
     qDebug () << "xml::saveEx 3";
-   root.appendChild(createExerciseNode(doc, name, group, muscle, info));
+    if(newName != "0")
+        root.appendChild(createExerciseNode(doc, newName, group, muscle, info));
+    else
+        root.appendChild(createExerciseNode(doc, name, group, muscle, info));
 
-   if(!file.open(QIODevice::WriteOnly))
-       return;
+    if(!file.open(QIODevice::WriteOnly))
+        return;
 
-   QTextStream ts2( &file );
-   ts2 << doc.toString();
+    QTextStream ts2( &file );
+    ts2 << doc.toString();
     qDebug () << "xml::saveEx 4";
-   file.close();
-   return;
+    file.close();
+    return;
 }
 
 void XML::saveCardio(QString name)
